netapp_ontap.resources.gcp_kms API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.gcp_kms`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

Google Cloud Key Management Services is a cloud key management service (KMS) that provides a secure store for encryption keys. This feature allows ONTAP to securely protect its encryption keys using Google Cloud KMS. In order to use Google Cloud KMS with ONTAP, a user must first deploy a Google Cloud application with appropriate access to the Google Cloud KMS and then provide ONTAP with the necessary details, such as, project ID, key ring name, location, key name and application credentials to allow ONTAP to communicate with the deployed Google Cloud application. The properties `state`, `google_reachability` and `ekmip_reachability` are considered advanced properties and are populated only when explicitly requested.

## Examples

### Enabling GCKMS for an SVM

The following example shows how to enable GCKMS at the SVM-scope. Note the return_records=true query parameter is used to obtain the newly created key manager configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms()
        resource.svm = {"uuid": "f36ff553-e713-11ea-bd56-005056bb4222"}
        resource.project_id = "testProj"
        resource.key_ring_name = "testKeyRing"
        resource.key_ring_location = "global"
        resource.key_name = "key1"
        resource.application_credentials = (
            '{"client_email": "my@account.email.com", "private_key": "ValidPrivateKey"}'
        )
        resource.post(hydrate=True)
        print(resource)

Try it out

    GcpKms(
        {
            "key_ring_location": "global",
            "_links": {
                "self": {
                    "href": "/api/security/gcp-kms/f72098a2-e908-11ea-bd56-005056bb4222"
                }
            },
            "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
            "project_id": "testProj",
            "key_name": "key1",
            "key_ring_name": "testKeyRing",
            "svm": {"name": "vs0", "uuid": "f36ff553-e713-11ea-bd56-005056bb4222"},
        }
    )

### Retrieving all GCKMS configurations

The following example shows how to retrieve all GCKMS configurations.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(GcpKms.get_collection(fields="*")))

Try it out

    [
        GcpKms(
            {
                "key_ring_location": "global",
                "_links": {
                    "self": {
                        "href": "/api/security/gcp-kms/f72098a2-e908-11ea-bd56-005056bb4222"
                    }
                },
                "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
                "project_id": "testProj",
                "key_name": "key1",
                "key_ring_name": "testKeyRing",
                "scope": "svm",
                "svm": {"name": "vs0", "uuid": "f36ff553-e713-11ea-bd56-005056bb4222"},
            }
        )
    ]

### Retrieving a specific GCKMS configuration

The following example shows how to retrieve information for a specific GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.get(fields="*")
        print(resource)

Try it out

    GcpKms(
        {
            "key_ring_location": "global",
            "_links": {
                "self": {
                    "href": "/api/security/gcp-kms/f72098a2-e908-11ea-bd56-005056bb4222"
                }
            },
            "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
            "project_id": "testProj",
            "key_name": "key1",
            "key_ring_name": "testKeyRing",
            "scope": "svm",
            "svm": {"name": "vs0", "uuid": "f36ff553-e713-11ea-bd56-005056bb4222"},
        }
    )

### Retrieving a specific GCKMS's advanced properties

The following example shows how to retrieve advanced properties for a specific GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.get(fields="state,google_reachability,ekmip_reachability")
        print(resource)

Try it out

    GcpKms(
        {
            "google_reachability": {"message": "", "code": "0", "reachable": True},
            "_links": {
                "self": {
                    "href": "/api/security/gcp-kms/f72098a2-e908-11ea-bd56-005056bb4222"
                }
            },
            "state": {
                "message": "The Google Cloud Key Management Service key protection is unavailable on the following nodes: cluster1-node1.",
                "code": "65537708",
                "cluster_state": False,
            },
            "uuid": "f72098a2-e908-11ea-bd56-005056bb4222",
            "ekmip_reachability": [
                {
                    "message": "",
                    "node": {
                        "name": "node1",
                        "_links": {
                            "self": {
                                "href": "/api/cluster/nodes/d208115f-7721-11eb-bf83-005056bb150e"
                            }
                        },
                        "uuid": "d208115f-7721-11eb-bf83-005056bb150e",
                    },
                    "code": "0",
                    "reachable": True,
                },
                {
                    "message": "",
                    "node": {
                        "name": "node2",
                        "_links": {
                            "self": {
                                "href": "/api/cluster/nodes/e208115f-7721-11eb-bf83-005056bb150e"
                            }
                        },
                        "uuid": "e208115f-7721-11eb-bf83-005056bb150e",
                    },
                    "code": "0",
                    "reachable": True,
                },
            ],
        }
    )

### Updating the application credentials of a specific GCKMS configuration

The following example shows how to update the application credentials for a specific GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.application_credentials = (
            '{"client_email": "new@account.com", "private_key": "ValidPrivateKey"}'
        )
        resource.patch()

### Updating the application credentials and applying a privileged account for impersonation.

The following example shows how to set a privileged account on an existing GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.application_credentials = '{"client_email": "unprivileged@account.com", "private_key": "ValidPrivateKeyforUnprivilegedAccount"}'
        resource.privileged_account = "privileged@account.com"
        resource.patch()

### Updating the authentication method to use GCE metadata server for retrieving short lived authentication tokens.

The following example shows how to change the authentication method on an existing GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.authentication_method = "sa_credentials_attachment"
        resource.patch()

### Changing the GCKMS key

The following example shows how to change the GCKMS key.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.rekey_external(
            body={
                "key_name": "key2",
                "key_ring_location": "global",
                "key_ring_name": "testKeyRing2",
                "project_id": "testProj2",
            }
        )

### Deleting a specific GCKMS configuration

The following example shows how to delete a specific GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="f72098a2-e908-11ea-bd56-005056bb4222")
        resource.delete()

### Restoring keys from a KMIP server

The following example shows how to restore keys for a GCKMS configuration.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import GcpKms

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = GcpKms(uuid="33820b57-ec90-11ea-875e-005056bbf3f0")
        resource.restore()

## Classes

`class GcpKms (*args, **kwargs)`

  Allows interaction with GcpKms objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all GcpKms resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('GcpKms')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a Google Cloud KMS configuration.

    ### Related ONTAP commands

    - `security key-manager external gcp disable`

    ### Learn more

    - `DOC /security/gcp-kms`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent GcpKms resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves Google Cloud KMS configurations for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external gcp show`
    - `security key-manager external gcp check`

    ### Learn more

    - `DOC /security/gcp-kms`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves Google Cloud KMS configurations for all clusters and SVMs.

    ### Related ONTAP commands

    - `security key-manager external gcp show`
    - `security key-manager external gcp check`

    ### Learn more

    - `DOC /security/gcp-kms`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('GcpKms')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the Google Cloud KMS configuration.

    ### Optional properties

    - `application_credentials` - New credentials used to verify the application's identity to the Google Cloud KMS.
    - `proxy_type` - Type of proxy (http/https) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `port` - Authorization server and Google Cloud KMS port number.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `project_id` - Google Cloud project (application) ID of the deployed Google Cloud application with appropriate access to the Google Cloud KMS.
    - `key_ring_name` - Google Cloud KMS key ring name of the deployed Google Cloud application with appropriate access to the specified Google Cloud KMS.
    - `key_ring_location` - Google Cloud KMS key ring location.
    - `cloudkms_host` - Google Cloud KMS host subdomain.
    - `oauth_host` - Open authorization server host name.
    - `oauth_url` - Open authorization URL for the access token.
    - `verify_host` - Verify the identity of the Google Cloud KMS host name.
    - `verify_ip` - Verify identity of Google Cloud KMS IP address.
    - `privileged_account` - Account used to impersonate Google Cloud KMS requests.
    - `authentication_method` - The authentication method to use for retrieving short lived authentication tokens.
    - `gce_metadata_server` - A custom metadata server URL used for retrieving short lived authentication tokens if the default service account is not used. This is only applicable when the `authentication_method` is set to `sa_credentials_attachment`.

    ### Related ONTAP commands

    - `security key-manager external gcp update-credentials`
    - `security key-manager external gcp update-config`

    ### Learn more

    - `DOC /security/gcp-kms`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('GcpKms')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[GcpKms], NetAppResponse]`

    Configures the Google Cloud KMS configuration for the specified SVM.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create a Google Cloud KMS.
    - `project_id` - Google Cloud project (application) ID of the deployed Google Cloud application with appropriate access to the Google Cloud KMS.
    - `key_ring_name` - Google Cloud KMS key ring name of the deployed Google Cloud application with appropriate access to the specified Google Cloud KMS.
    - `key_ring_location` - Google Cloud KMS key ring location.
    - `key_name`- Key Identifier of the Google Cloud KMS key encryption key.
    - `application_credentials` - The Google Cloud application's service account credentials required to access the specified KMS. This is a JSON file containing an email address and the private key of the service account holder. The field is required if the `authentication_method` is set to `application_credentials_key`.

    ### Optional properties

    - `proxy_type` - Type of proxy (http/https) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `port` - Authorization server and Google Cloud KMS port number.
    - `cloudkms_host` - Google Cloud KMS host subdomain.
    - `oauth_host` - Open authorization server host name.
    - `oauth_url` - Open authorization URL for the access token.
    - `privileged_account` - Account used to impersonate Google Cloud KMS requests.
    - `verify_ip` - Verify identity of Google Cloud KMS IP address.
    - `verify_host` - Verify the identity of the Google Cloud KMS host name.
    - `authentication_method` - The authentication method to use for retrieving short lived authentication tokens.
    - `gce_metadata_server` - A custom metadata server URL used for retrieving short lived authentication tokens if the default service account is not used. This is only applicable when the `authentication_method` is set to `sa_credentials_attachment`.

    ### Related ONTAP commands

    - `security key-manager external gcp enable`

    ### Learn more

    - `DOC /security/gcp-kms`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes a Google Cloud KMS configuration.

    ### Related ONTAP commands

    - `security key-manager external gcp disable`

    ### Learn more

    - `DOC /security/gcp-kms`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the Google Cloud KMS configuration for the SVM specified by the UUID.

    ### Related ONTAP commands

    - `security key-manager external gcp show`
    - `security key-manager external gcp check`

    ### Learn more

    - `DOC /security/gcp-kms`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the Google Cloud KMS configuration.

    ### Optional properties

    - `application_credentials` - New credentials used to verify the application's identity to the Google Cloud KMS.
    - `proxy_type` - Type of proxy (http/https) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `port` - Authorization server and Google Cloud KMS port number.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `project_id` - Google Cloud project (application) ID of the deployed Google Cloud application with appropriate access to the Google Cloud KMS.
    - `key_ring_name` - Google Cloud KMS key ring name of the deployed Google Cloud application with appropriate access to the specified Google Cloud KMS.
    - `key_ring_location` - Google Cloud KMS key ring location.
    - `cloudkms_host` - Google Cloud KMS host subdomain.
    - `oauth_host` - Open authorization server host name.
    - `oauth_url` - Open authorization URL for the access token.
    - `verify_host` - Verify the identity of the Google Cloud KMS host name.
    - `verify_ip` - Verify identity of Google Cloud KMS IP address.
    - `privileged_account` - Account used to impersonate Google Cloud KMS requests.
    - `authentication_method` - The authentication method to use for retrieving short lived authentication tokens.
    - `gce_metadata_server` - A custom metadata server URL used for retrieving short lived authentication tokens if the default service account is not used. This is only applicable when the `authentication_method` is set to `sa_credentials_attachment`.

    ### Related ONTAP commands

    - `security key-manager external gcp update-credentials`
    - `security key-manager external gcp update-config`

    ### Learn more

    - `DOC /security/gcp-kms`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Configures the Google Cloud KMS configuration for the specified SVM.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create a Google Cloud KMS.
    - `project_id` - Google Cloud project (application) ID of the deployed Google Cloud application with appropriate access to the Google Cloud KMS.
    - `key_ring_name` - Google Cloud KMS key ring name of the deployed Google Cloud application with appropriate access to the specified Google Cloud KMS.
    - `key_ring_location` - Google Cloud KMS key ring location.
    - `key_name`- Key Identifier of the Google Cloud KMS key encryption key.
    - `application_credentials` - The Google Cloud application's service account credentials required to access the specified KMS. This is a JSON file containing an email address and the private key of the service account holder. The field is required if the `authentication_method` is set to `application_credentials_key`.

    ### Optional properties

    - `proxy_type` - Type of proxy (http/https) if proxy configuration is used.
    - `proxy_host` - Proxy hostname if proxy configuration is used.
    - `proxy_port` - Proxy port number if proxy configuration is used.
    - `proxy_username` - Proxy username if proxy configuration is used.
    - `proxy_password` - Proxy password if proxy configuration is used.
    - `port` - Authorization server and Google Cloud KMS port number.
    - `cloudkms_host` - Google Cloud KMS host subdomain.
    - `oauth_host` - Open authorization server host name.
    - `oauth_url` - Open authorization URL for the access token.
    - `privileged_account` - Account used to impersonate Google Cloud KMS requests.
    - `verify_ip` - Verify identity of Google Cloud KMS IP address.
    - `verify_host` - Verify the identity of the Google Cloud KMS host name.
    - `authentication_method` - The authentication method to use for retrieving short lived authentication tokens.
    - `gce_metadata_server` - A custom metadata server URL used for retrieving short lived authentication tokens if the default service account is not used. This is only applicable when the `authentication_method` is set to `sa_credentials_attachment`.

    ### Related ONTAP commands

    - `security key-manager external gcp enable`

    ### Learn more

    - `DOC /security/gcp-kms`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def rekey_external (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Rekeys the external key in the key hierarchy for an SVM with a Google Cloud KMS configuration.

    ### Required properties

    - `key_name` - Google Cloud KMS key name.

    ### Optional properties

    - `project_id` - Google Cloud KMS project ID.
    - `key_ring_location` - Google Cloud KMS key ring location.
    - `key_ring_name` - Google Cloud KMS key ring name.

    ### Related ONTAP commands

    - `security key-manager external gcp rekey-external`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def rekey_internal (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Rekeys the internal key in the key hierarchy for an SVM with a Google Cloud KMS configuration.

    ### Related ONTAP commands

    - `security key-manager external gcp rekey-internal`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def restore (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Restores the keys for an SVM from a configured Google Cloud KMS.

    ### Related ONTAP commands

    - `security key-manager external gcp restore`

    Perform a custom action on this resource which is not a simple CRUD action

    ## Args

    `path`
      The action verb for this request. This will be added as a postfix to the instance location of the resource.
    `body`
      The body of the action request. This should be a Resource instance. The connection and URL will be determined based on the values from this object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class GcpKmsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the GcpKms object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `application_credentials: str POST PATCH`

    The Google Cloud application's service account credentials required to access the specified KMS. The client_email and private_key fields of the service account holder are required. The credentials are required if the `authentication_method` is set to `application_credentials_key`.

    Example: {"private_key":"ValidPrivateKey","client_email":"my@account.email.com"}

  `authentication_method: str GET POST PATCH`

    Google Cloud KMS authentication method.

    Valid choices:

    - application_credentials_key
    - sa_credentials_attachment
  `caller_account: str GET`

    Google Cloud KMS caller account email

    Example: myaccount@myproject.com

  `cloudkms_host: str GET POST PATCH`

    Google Cloud KMS host subdomain.

    Example: cloudkms.googleapis.com

  `ekmip_reachability: List[AzureKeyVaultEkmipReachability] GET`

    Provides the connectivity status for the given SVM on the given node to all EKMIP servers configured on all nodes of the cluster. This is an advanced property; there is an added computational cost to retrieving its value. The property is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter or GET for all advanced properties is enabled.

  `gce_metadata_server: str GET POST PATCH`

    A custom metadata server URL used for retrieving short lived authentication tokens if the default service account is not used. This is only applicable when the `authentication_method` is set to `sa_credentials_attachment`.

    Example: http://169.254.169.254/computeMetadata/v1/instance/service-accounts/default/token

  `google_reachability: GcpConnectivity GET`

    Indicates whether or not the Google Cloud KMS is reachable from all nodes in the cluster. This is an advanced property; there is an added computational cost to retrieving its value. The property is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter or GET for all advanced properties is enabled.

  `key_name: str GET POST`

    Key Identifier of Google Cloud KMS key encryption key.

    Example: cryptokey1

  `key_ring_location: str GET POST`

    Google Cloud KMS key ring location.

    Example: global

  `key_ring_name: str GET POST`

    Google Cloud KMS key ring name of the deployed Google Cloud application.

    Example: gcpapp1-keyring

  `links: SelfLink GET`

    The links field of the gcp_kms.

  `oauth_host: str GET POST PATCH`

    Open authorization server host name.

    Example: oauth2.googleapis.com

  `oauth_url: str GET POST PATCH`

    Open authorization URL for the access token.

    Example: https://oauth2.googleapis.com/token

  `port: Size GET POST PATCH`

    Authorization server and Google Cloud KMS port number.

    Example: 443

  `privileged_account: str GET POST PATCH`

    Google Cloud KMS account to impersonate.

    Example: myserviceaccount@myproject.iam.gserviceaccount.com

  `project_id: str GET POST`

    Google Cloud project (application) ID of the deployed Google Cloud application that has appropriate access to the Google Cloud KMS.

    Example: gcpapp1

  `proxy_host: str GET POST PATCH`

    Proxy host name.

    Example: proxy.eng.com

  `proxy_password: str POST PATCH`

    Proxy password. Password is not audited.

    Example: proxypassword

  `proxy_port: Size GET POST PATCH`

    Proxy port number.

    Example: 1234

  `proxy_type: str GET POST PATCH`

    Type of proxy.

    Valid choices:

    - http
    - https
  `proxy_username: str GET POST PATCH`

    Proxy username.

    Example: proxyuser

  `scope: str GET`

    Set to "svm" for interfaces owned by an SVM. Otherwise, set to "cluster".

    Valid choices:

    - svm
    - cluster
  `state: GcpKmsState GET`

    Google Cloud Key Management Services is a cloud key management service (KMS) that provides a secure store for encryption keys. This object indicates whether or not the Google Cloud KMS key protection is available on all nodes in the cluster. This is an advanced property; there is an added computational cost to retrieving its value. The property is not populated for either a collection GET or an instance GET unless it is explicitly requested using the `fields` query parameter or GET for all advanced properties is enabled.

  `svm: Svm GET POST`

    The svm field of the gcp_kms.

  `uuid: str GET`

    A unique identifier for the Google Cloud KMS.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412

  `verify_host: bool GET POST PATCH`

    Verify the identity of the Google Cloud KMS host name.

  `verify_ip: bool GET POST PATCH`

    Verify the identity of the Google Cloud KMS IP address.